//+------------------------------------------------------------------+
//|                                                       MovChi.mq4 |
//|                                         Copyright 2015, Chistabo |
//| Based on ManChi EA (= ManChi EA updated)      chistabo@gmail.com |
//+------------------------------------------------------------------+
// Moving average 2x, if:
// a) both MAs and 'Hi/Lo signal' go same direction - trade
// b) slow MA and 'Hi/Lo signal' goes one, and fast MA goes opposite direction - trade
#property copyright "Copyright 2015, Chistabo"
#property link      "chistabo@gmail.com"
#property version   "1.0"
#property strict
#include <ChiFunctions.mqh>
// --- EXTERNAL VARIABLES ---------------------------------------------------------------------------------
extern string Note_Money_management="Money management"; // Money management
extern double RiskPerTrade=2.0; //Risk % per trade
extern string Note_Stop_loss_settings="If Fixed SL=0, Auto Hi/Lo SL will be used"; // Stop loss calculations
extern int FixedSL=210; // Fixed SL (in pips)
extern int AutoHiLoSLTF=60; // Auto Hi/Lo SL timeframe
extern int AutoHiLoSLBB=1; // Auto Hi/Lo SL bars back
extern string Note_Fixed_take_profit_percent="If 0.0 - don't use fixed TP"; // Fixed take profit in % of account balance
extern double FixedTPPercent=0.0; // Fixed take profit percent
extern string Note_Signal_bar_high_low="If price > previous bar - buy signal, else sell signal"; // Signal bar hi/lo
extern int SignalBarTF=15; // Signal bar timeframe
extern string Note_Break_even="BE button will toggle: off/fixed/trail/trailHiLo BE"; // Break even settings
extern int BEWhenPrice=210; // BE when price (in pips)
extern int MoveSLTo=50; // Move SL to X pips from open price
extern int BETF=60; // BE timeframe
extern int BEBB=1; // BE bars back
extern string Note_Trail_buy_sell_SL="Trail button will toggle: off/fixed(w/factor)/HiLo trail"; // Trail buy/sell orders SL
extern int FixedTrailOrdersSL=210; // Fixed trail SL (in pips)
extern double FixedTrailOrdersSLFactor=1.3; // Fixed trail SL factor
extern int AutoTrailOrdersTF=1440; // Auto hi/lo trail timeframe
extern int AutoTrailOrdersBB=1; // Auto hi/lo trail bars back
                                // --- ADDITIONAL FILTER ----------------------------------------------------------------------------------
extern bool ShowMAInfo=true;
extern string Note_SMASettings="Slow MA (method=LWMA, price=close)"; // Slow moving average
extern int SMATF=1440; // Slow MA timeframe
extern int SMAPeriod=5; // Slow MA period
extern int SMADiff=89; // Slow MA difference
int SMAMethod=3; // 0:SMA   1:EMA  2:SMMA 3:LWMA - fixed
int SMAPrice=0; // 0:Close 1:Open 2:High 3:Low 4:Median 5:Typical 6:Weighted - fixed
int SMAShift=0;
extern string Note_FMASettings="Fast MA (method=LWMA, price=close)"; // Fast moving average
extern int FMATF=60; // Fast MA timeframe
extern int FMAPeriod=5; // Fast MA period
extern int FMADiff=55; // Fast MA difference
int FMAMethod=3; // 0:SMA   1:EMA  2:SMMA 3:LWMA - fixed
int FMAPrice=0; // 0:Close 1:Open 2:High 3:Low 4:Median 5:Typical 6:Weighted - fixed
int FMAShift=0;
// --- TRAIL HORIZONTAL LINE ------------------------------------------------------------------------------
extern string Note_Trail_h_line="Put 'line orders' into line's Description field"; // Put 'above/below' into line's Name field
extern int TrailHLineTF=240; // Trail horizontal line timeframe
extern int TrailHLineBB=3; // Trail horizontal line bars back
extern int TrailHLinePips=0; // Trail horizontal line in pips
extern bool ShowLineOrders=false; // Show 'line orders'?
                                  // ----- NOTIFICATIONS ------------------------------------------------------------------------------------
extern string Note_Notifications="Notifications settings"; // Notifications
extern bool PopUpSignalAlerts=false; // Pop-up signal alerts
extern string WhichSignalSound="bells"; // Use sound (wav) for signal
extern string AlertSound="siren"; // Use sound (wav) for alert
                                  // --- GLOBAL VARIABLES -----------------------------------------------------------------------------------
enum TRADE_TYPE{DontTradeType,TradeType,BuyOnlyType,SellOnlyType};TRADE_TYPE Trade_type;
enum BREAK_EVEN_TYPE{DontBEType,BEStandardType,BETrailType};BREAK_EVEN_TYPE BE_type;
bool BuyOnly,SellOnly,Trade;
const color btn_bordClr=clrWhiteSmoke;
string Test;
//+------------------------------------------------------------------+
//| Expert initialization function                                   |
//+------------------------------------------------------------------+
int OnInit()
  {
   CreateButtons();
   ReadGV();
   SetBtnText("Trade_btn");SetBtnText("BE_btn");
   CheckRisk();
   if(IsTesting())Test="_test";
   return(INIT_SUCCEEDED);
  }
//+------------------------------------------------------------------+
//| Expert deinitialization function                                 |
//+------------------------------------------------------------------+
void OnDeinit(const int reason)
  {
   StoreGV();
   DeleteButtons();
  }
//+------------------------------------------------------------------+
//| Expert tick function                                             |
//+------------------------------------------------------------------+
void OnTick()
  {
  }
//+------------------------------------------------------------------+
//| Tester function                                                  |
//+------------------------------------------------------------------+
double OnTester()
  {
   double ret=0.0;
   return(ret);
  }
//+------------------------------------------------------------------+
//| ChartEvent function                                              |
//+------------------------------------------------------------------+
void OnChartEvent(const int id,const long &lparam,const double &dparam,const string &sparam)
  {
   ResetLastError();
   if(id==CHARTEVENT_OBJECT_CLICK)
     {
      if(ObjectType(sparam)==OBJ_BUTTON){ButtonPressed(0,sparam);}
     }
//   ChartRedraw();
  }
//+------------------------------------------------------------------+
//| CUSTOM FUNCTIONS                                                 |
//+------------------------------------------------------------------+
// --- CREATE BUTTONS ON CHART (OnInit) -------------------------------------------------------------------
void CreateButtons()
  {
   int btn_rightOffset=5;int btn_fontSize=9;int spaceBtwButtons=5;/*string btn_text;*/int btn_width=60;
   int btn_x=btn_width+btn_rightOffset;int btn_y=20;int btn_height=3*btn_fontSize;ENUM_BASE_CORNER btn_corner=CORNER_RIGHT_UPPER;
   string btn_font="Arial";color btn_txtClr=clrWhite;color btn_bgndClr=clrBlack;
   int btn_addNextRow=btn_height+spaceBtwButtons;

   if(!ButtonCreate(0,"Trade_btn",0,btn_x,btn_y,btn_width,btn_height,btn_corner,"Trade",btn_font,btn_fontSize,btn_txtClr,btn_bgndClr,
      btn_bordClr))return;
   if(!ButtonCreate(0,"BE_btn",0,btn_x,btn_y+1*btn_addNextRow,btn_width,btn_height,btn_corner,"No Be",btn_font,btn_fontSize,btn_txtClr,
      btn_bgndClr,btn_bordClr))return;
   if(!ButtonCreate(0,"Trail_btn",0,btn_x,btn_y+2*btn_addNextRow,btn_width,btn_height,btn_corner,"Trail",btn_font,btn_fontSize,btn_txtClr,
      btn_bgndClr,btn_bordClr))return;
   if(!ButtonCreate(0,"Close_btn",0,btn_x,btn_y+3*btn_addNextRow,btn_width,btn_height,btn_corner,"Close",btn_font,btn_fontSize,btn_txtClr,
      btn_bgndClr,btn_bordClr))return;
   ChartRedraw();
  }
// --- DELETE BUTTONS ON CHART (OnDeinit) -----------------------------------------------------------------
void DeleteButtons()
  {
   ButtonDelete(0,"Trade_btn");ButtonDelete(0,"BE_btn");ButtonDelete(0,"Trail_btn");ButtonDelete(0,"Close_btn");
  }
// --- BUTTON PRESSED -------------------------------------------------------------------------------------
void ButtonPressed(const long chartID,const string sparam)
  {
   ObjectSetInteger(chartID,sparam,OBJPROP_BORDER_COLOR,clrBlack);
   ChartRedraw();
   if(sparam=="Trade_btn")TradeBtnToggle(sparam);
   if(sparam=="BE_btn")BEBtnToggle(sparam);
   Sleep(100);ObjectSetInteger(0,sparam,OBJPROP_BORDER_COLOR,btn_bordClr);ChartRedraw();
  }
// --- SET BUTTON TEXT AND COLOR --------------------------------------------------------------------------
void SetBtnText(const string sparam)
  {
   color inactive=C'72,72,7	2';
   if(sparam=="Trade_btn")
     {
      switch(Trade_type)
        {
         case DontTradeType:
           {
            ObjectSetString(0,sparam,OBJPROP_TEXT,"No Trd");ObjectSetInteger(0,sparam,OBJPROP_COLOR,inactive);
            ObjectSetString(0,sparam,OBJPROP_TOOLTIP,"Not trading");break;
           }
         case TradeType:
           {
            ObjectSetString(0,sparam,OBJPROP_TEXT,"Trade");ObjectSetInteger(0,sparam,OBJPROP_COLOR,clrLimeGreen);
            ObjectSetString(0,sparam,OBJPROP_TOOLTIP,"Trading buy & sell");break;
           }
         case BuyOnlyType:
           {
            ObjectSetString(0,sparam,OBJPROP_TEXT,"Buy");ObjectSetInteger(0,sparam,OBJPROP_COLOR,clrDodgerBlue);
            ObjectSetString(0,sparam,OBJPROP_TOOLTIP,"Trading buy only");break;
           }
         case SellOnlyType:
           {
            ObjectSetString(0,sparam,OBJPROP_TEXT,"Sell");ObjectSetInteger(0,sparam,OBJPROP_COLOR,clrRed);
            ObjectSetString(0,sparam,OBJPROP_TOOLTIP,"Trading sell only"); break;
           }
        }
     }
   if(sparam=="BE_btn")
     {
      switch(BE_type)
        {
         case DontBEType:
           {
            ObjectSetString(0,sparam,OBJPROP_TEXT,"No BE");ObjectSetInteger(0,sparam,OBJPROP_COLOR,inactive);
            ObjectSetString(0,sparam,OBJPROP_TOOLTIP,"Not using break even"); break;
           }
         case BEStandardType:
           {
            ObjectSetString(0,sparam,OBJPROP_TEXT,"BE nrm");ObjectSetInteger(0,sparam,OBJPROP_COLOR,clrYellowGreen);
            ObjectSetString(0,sparam,OBJPROP_TOOLTIP,"Using standard break even"); break;
           }
         case BETrailType:
           {
            ObjectSetString(0,sparam,OBJPROP_TEXT,"BE trl");ObjectSetInteger(0,sparam,OBJPROP_COLOR,clrLimeGreen);
            ObjectSetString(0,sparam,OBJPROP_TOOLTIP,"Using trail to break even"); break;
           }
        }
     }
   Print("-SetBtnTextF()- sparam= "+sparam); // test     
  }
//--- READ GLOBAL VARIABLES OnInit ------------------------------------------------------------------------
void ReadGV()
  {
   Trade_type=(TRADE_TYPE)GetGV("TradeType"+Test);
   BE_type=(BREAK_EVEN_TYPE)GetGV("BE_type"+Test);
//TradeDirection=GetGV("TradeDirection"+Test);
//  BreakEven=GetGV("BreakEven"+Test);
//  SignalBarTF=GetGV("SignalBarTF"+Test);
  }
//--- STORE GLOBAL VARIABLES OnDeinit() -------------------------------------------------------------------
void StoreGV()
  {
   SetGV("TradeType"+Test,Trade_type);
   SetGV("BE_type"+Test,BE_type);
//  SetGV("TradeDirection"+Test,TradeDirection);
//  SetGV("BreakEven"+Test,BreakEven);
//  SetGV("SignalBarTF"+Test,SignalBarTF);
  }
// --- TRADE BUTTON TOGGLE --------------------------------------------------------------------------------
void TradeBtnToggle(const string sparam)
  {
   switch(Trade_type)
     {
      case DontTradeType:
        {Trade=true;BuyOnly=false;SellOnly=false;Trade_type=TradeType;SetBtnText(sparam);break;}
      case TradeType:
        {Trade=true;BuyOnly=true;SellOnly=false;Trade_type=BuyOnlyType;SetBtnText(sparam);break;}
      case BuyOnlyType:
        {Trade=true;BuyOnly=false;SellOnly=true;Trade_type=SellOnlyType;SetBtnText(sparam);break;}
      case SellOnlyType:
        {Trade=false;Trade_type=DontTradeType;SetBtnText(sparam);break;}
     }
     Print("-TradeBtnToggleF()- Trade_type= "+EnumToString(Trade_type)); // test
  }
// --- BREAK EVEN TYPE BUTTON TOGGLE --------------------------------------------------------------------
void BEBtnToggle(const string sparam)
  {
   switch(BE_type)
     {
      case DontBEType:{BE_type=BEStandardType;SetBtnText(sparam);break;}
      case BEStandardType:{BE_type=BETrailType;SetBtnText(sparam);break;}
      case BETrailType:{BE_type=DontBEType;SetBtnText(sparam);break;}
     }
   Print("-BEBtnToggleF()- BE_type= "+EnumToString(BE_type)); // test
  }
